@@ -41,8 +41,6 @@
 
 #define KPIPEWIRE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 #if defined(KPIPEWIRE_NO_DEPRECATED)
 #  undef KPIPEWIRE_DEPRECATED
 #  define KPIPEWIRE_DEPRECATED_EXPORT KPIPEWIRE_EXPORT
@@ -63,7 +61,7 @@
 #define KPIPEWIRE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPIPEWIRE_NO_DEPRECATED
-#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b05
+#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b07
 #endif
 #ifdef KPIPEWIRE_NO_DEPRECATED_WARNINGS
 #  define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0
@@ -73,7 +71,7 @@
 #  ifdef KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0x51b05
+#    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0x51b07
 #  endif
 #endif
 
@@ -82,7 +80,7 @@
 #endif
 
 #ifdef KPIPEWIRE_DEPRECATED
-#  define KPIPEWIRE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KPIPEWIRE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KPIPEWIRE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
